@@ -40,7 +40,7 @@
  */
 
 /*
- * $Id: pop3proxyd.c,v 1.11 2001/02/16 18:55:10 leg Exp $
+ * $Id: pop3proxyd.c,v 1.16 2001/04/26 17:18:26 leg Exp $
  */
 #include <config.h>
 
@@ -117,13 +117,16 @@ struct protstream *backend_out, *backend_in;
 int backend_sock;
 sasl_conn_t *backend_saslconn;
 
+static void cmd_apop(char *user, char *digest);
+static int apop_enabled(void);
+static char popd_apop_chal[300]; /* timestamp (44) + config_servername (256) */
+
 static void cmd_auth();
 static void cmd_capa();
 static void cmd_pass();
 static void cmd_user();
 static void cmd_starttls(int pop3s);
 static int starttls_enabled(void);
-void eatline(void);
 static void cmdloop(void);
 static void kpop(void);
 static void usage(void);
@@ -195,8 +198,11 @@ int service_main(int argc, char **argv, char **envp)
     popd_in = prot_new(0, 0);
     popd_out = prot_new(1, 1);
 
-    while ((opt = getopt(argc, argv, "sk")) != EOF) {
+    while ((opt = getopt(argc, argv, "C:sk")) != EOF) {
 	switch(opt) {
+	case 'C': /* alt config file - handled by service::main() */
+	    break;
+
 	case 's': /* pop3s (do starttls right away) */
 	    pop3s = 1;
 	    if (!starttls_enabled()) {
@@ -260,7 +266,8 @@ int service_main(int argc, char **argv, char **envp)
     if (pop3s == 1) cmd_starttls(1);
 
     prot_printf(popd_out, "+OK %s Cyrus POP3 Murder %s server ready\r\n",
-		config_servername, CYRUS_VERSION);
+		apop_enabled() ? popd_apop_chal : config_servername,
+		CYRUS_VERSION);
     cmdloop();
     
     return 0;
@@ -275,7 +282,9 @@ void service_abort(int error)
 
 void usage(void)
 {
-    prot_printf(popd_out, "-ERR usage: pop3d [-k] [-s]\r\n");
+    prot_printf(popd_out,
+		"-ERR usage: pop3proxyd [-C <alt_config>]"
+		" [-k] [-s]\r\n");
     prot_flush(popd_out);
     exit(EC_USAGE);
 }
@@ -447,7 +456,8 @@ static void cmdloop(void)
 		cmd_capa();
 	    }
 	}
-	else if (!strcmp(inputbuf, "user")) {
+	else if (!strcmp(inputbuf, "user") &&
+		 (popd_starttls_done || config_getswitch("allowplaintext", 1))) {
 	    if (!arg) {
 		prot_printf(popd_out, "-ERR Missing argument\r\n");
 	    }
@@ -455,10 +465,27 @@ static void cmdloop(void)
 		cmd_user(arg);
 	    }
 	}
-	else if (!strcmp(inputbuf, "pass")) {
+	else if (!strcmp(inputbuf, "pass") &&
+		 (popd_starttls_done || config_getswitch("allowplaintext", 1))) {
 	    if (!arg) prot_printf(popd_out, "-ERR Missing argument\r\n");
 	    else cmd_pass(arg);
 	}
+	else if (!strcmp(inputbuf, "apop") && apop_enabled()) {
+	    char *user, *digest;
+
+	    /* Parse into user and digest */
+	    if (arg) arg = strchr(user = arg, ' ');
+	    if (!arg) prot_printf(popd_out, "-ERR Missing argument\r\n");
+	    else {
+		*arg++ = '\0';
+		digest = arg;
+		/* per RFC 1939, digest must be 32 hex digits */
+		while (*arg && isxdigit((int) *arg)) arg++;
+		if ((arg - digest) != 32)
+		    prot_printf(popd_out, "-ERR Invalid digest string\r\n");
+		else cmd_apop(user, digest);
+	    }
+	}
 	else if (!strcmp(inputbuf, "auth")) {
 	    cmd_auth(arg);
 	}
@@ -582,6 +609,94 @@ static void cmd_starttls(int pop3s)
 }
 #endif /* HAVE_SSL */
 
+#ifdef HAVE_APOP
+static int apop_enabled(void)
+{
+    static int chal_done = 0;
+
+    /* Create APOP challenge string for banner */
+    if (!chal_done &&
+	!sasl_mkchal(popd_saslconn, popd_apop_chal, sizeof(popd_apop_chal), 1)) {
+	syslog(LOG_WARNING,
+	       "can't create APOP challenge string - APOP disabled");
+	popd_apop_chal[0] = '\0';
+    }
+
+    chal_done = 1;
+    return *popd_apop_chal;
+}
+
+static void cmd_apop(char *user, char *digest)
+{
+    int fd;
+    struct protstream *shutdown_in;
+    char buf[1024];
+    char *p;
+    char shutdownfilename[1024];
+    char *reply = 0;
+
+    if (popd_userid) {
+	prot_printf(popd_out, "-ERR Must give PASS command\r\n");
+	return;
+    }
+
+    sprintf(shutdownfilename, "%s/msg/shutdown", config_dir);
+    if ((fd = open(shutdownfilename, O_RDONLY, 0)) != -1) {
+	shutdown_in = prot_new(fd, 0);
+	prot_fgets(buf, sizeof(buf), shutdown_in);
+	if ((p = strchr(buf, '\r'))!=NULL) *p = 0;
+	if ((p = strchr(buf, '\n'))!=NULL) *p = 0;
+
+	for(p = buf; *p == '['; p++); /* can't have [ be first char */
+	prot_printf(popd_out, "-ERR %s\r\n", p);
+	prot_flush(popd_out);
+	shut_down(0);
+    }
+    else if (!(p = auth_canonifyid(user)) ||
+	       strchr(p, '.') || strlen(p) + 6 > MAX_MAILBOX_PATH) {
+	prot_printf(popd_out, "-ERR Invalid user\r\n");
+	syslog(LOG_NOTICE,
+	       "badlogin: %s APOP %s invalid user",
+	       popd_clienthost, beautify_string(user));
+	return;
+    }
+    else if ((sasl_checkapop(popd_saslconn,
+			     p,
+			     strlen(p),
+			     popd_apop_chal,
+			     strlen(popd_apop_chal),
+			     digest,
+			     strlen(digest),
+			     (const char **) &reply))!=SASL_OK) { 
+	if (reply) {
+	    syslog(LOG_NOTICE, "badlogin: %s APOP %s %s",
+		   popd_clienthost, p, reply);
+	}
+	sleep(3);
+	prot_printf(popd_out, "-ERR Invalid login\r\n");
+	return;
+    }
+    else {
+	popd_userid = xstrdup(p);
+	syslog(LOG_NOTICE, "login: %s %s APOP %s",
+	       popd_clienthost, popd_userid, reply ? reply : "");
+    }
+    openproxy();
+    popd_auth_done = 1;
+}
+#else
+static int apop_enabled(void)
+{
+    return 0;
+}
+
+static void cmd_apop(char *user __attribute__((unused)),
+		     char *digest __attribute__((unused)))
+{
+    fatal("cmd_apop() called, but no sasl_checkapop()", EC_SOFTWARE);
+}
+#endif /* HAVE_APOP */
+
 void
 cmd_user(user)
 char *user;
@@ -715,7 +830,10 @@ cmd_capa()
     prot_printf(popd_out, "TOP\r\n");
     prot_printf(popd_out, "UIDL\r\n");
     prot_printf(popd_out, "PIPELINING\r\n");
-    prot_printf(popd_out, "USER\r\n");
+
+    if (popd_starttls_done || config_getswitch("allowplaintext", 1)) {
+	prot_printf(popd_out, "USER\r\n");
+    }
     
     prot_printf(popd_out,
 		"IMPLEMENTATION Cyrus POP3 proxy server %s\r\n",
@@ -1057,16 +1175,6 @@ static void openproxy(void)
     return;
 }
 
-/*
- * Eat characters up to and including the next newline
- */
-void eatline(void)
-{
-    int c;
-
-    while ((c = prot_getc(popd_in)) != EOF && c != '\n') ;
-}
-
 /* we've authenticated the client, we've connected to the backend.
    now it's all up to them */
 static void bitpipe(void)
