@@ -39,7 +39,7 @@
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
  */
-/* $Id: quota.c,v 1.36 2000/12/18 04:53:41 leg Exp $ */
+/* $Id: quota.c,v 1.38 2001/03/05 22:27:25 leg Exp $ */
 
 
 #include <config.h>
@@ -100,8 +100,6 @@ int fixquota_fixroot(struct mailbox *mailbox,
 		     char *root);
 int fixquota_finish(int thisquota);
 
-extern char *mailbox_findquota();
-
 struct quotaentry {
     struct quota quota;
     int refcount;
@@ -124,13 +122,16 @@ int main(int argc,char **argv)
     int opt;
     int fflag = 0;
     int r, code = 0;
-
-    config_init("quota");
+    char *alt_config = NULL;
 
     if (geteuid() == 0) fatal("must run as the Cyrus user", EC_USAGE);
 
-    while ((opt = getopt(argc, argv, "f")) != EOF) {
+    while ((opt = getopt(argc, argv, "C:f")) != EOF) {
 	switch (opt) {
+	case 'C': /* alt config file */
+	    alt_config = optarg;
+	    break;
+
 	case 'f':
 	    fflag = 1;
 	    break;
@@ -140,6 +141,8 @@ int main(int argc,char **argv)
 	}
     }
 
+    config_init(alt_config, "quota");
+
     r = buildquotalist(argv+optind, argc-optind);
 
     if (!r && fflag) {
@@ -162,7 +165,7 @@ int main(int argc,char **argv)
 
 void usage(void)
 {
-    fprintf(stderr, "usage: quota [-f] [prefix]...\n");
+    fprintf(stderr, "usage: quota [-C <alt_config>] [-f] [prefix]...\n");
     exit(EC_USAGE);
 }    
 
